# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to
[Semantic Versioning](https://semver.org/spec/v2.0.0.html). the
[PEP 440 version scheme](https://peps.python.org/pep-0440/#version-scheme).

## [Unreleased]

### Added

### Changed

### Fixed

### Removed

### Security
